@@ -23,7 +23,7 @@ from aliyunsdkdbfs.endpoint import endpoint_data
 class DeleteDbfsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'DBFS', '2020-04-18', 'DeleteDbfs','dbfs')
+		RpcRequest.__init__(self, 'DBFS', '2020-04-18', 'DeleteDbfs')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -36,3 +36,8 @@ class DeleteDbfsRequest(RpcRequest):
 
 	def set_FsId(self, FsId):  # String
 		self.add_query_param('FsId', FsId)
+	def get_Force(self): # Boolean
+		return self.get_query_params().get('Force')
+
+	def set_Force(self, Force):  # Boolean
+		self.add_query_param('Force', Force)
